@@ -93,94 +93,94 @@ KPKG::KPKG(TDEConfig *_config)
 void KPKG::setupMenu()
 {
 
-  pack_open = KStdAction::open(TQT_TQOBJECT(kpackage), TQT_SLOT(fileOpen()),
+  pack_open = KStdAction::open(kpackage, TQ_SLOT(fileOpen()),
 			       actionCollection());
 
-  recent = KStdAction::openRecent(TQT_TQOBJECT(this), TQT_SLOT(openRecent(const KURL&)),
+  recent = KStdAction::openRecent(this, TQ_SLOT(openRecent(const KURL&)),
 				  actionCollection());
   recent->loadEntries( config );
 
   pack_find = new TDEAction( i18n("Find &Package..."), "edit-find",
-			   TDEStdAccel::shortcut(TDEStdAccel::Find), TQT_TQOBJECT(kpackage),
-			   TQT_SLOT(find()), actionCollection(), "pack_find");
+			   TDEStdAccel::shortcut(TDEStdAccel::Find), kpackage,
+			   TQ_SLOT(find()), actionCollection(), "pack_find");
 
   pack_findf = new TDEAction( i18n("Find &File..."), "filefind",
-			    0, TQT_TQOBJECT(kpackage),
-			    TQT_SLOT(findf()), actionCollection(), "pack_findf");
+			    0, kpackage,
+			    TQ_SLOT(findf()), actionCollection(), "pack_findf");
 
   kpack_reload = new TDEAction( i18n("&Reload"), "reload",
-			      TDEStdAccel::shortcut(TDEStdAccel::Reload), TQT_TQOBJECT(kpackage),
-			      TQT_SLOT(reload()), actionCollection(), "kpack_reload");
+			      TDEStdAccel::shortcut(TDEStdAccel::Reload), kpackage,
+			      TQ_SLOT(reload()), actionCollection(), "kpack_reload");
 
-  (void) KStdAction::quit(TQT_TQOBJECT(kpackage), TQT_SLOT(fileQuit()),
+  (void) KStdAction::quit(kpackage, TQ_SLOT(fileQuit()),
 			  actionCollection());
 
-  pack_prev = KStdAction::back(TQT_TQOBJECT(kpackage->management->treeList), TQT_SLOT(previous()),
+  pack_prev = KStdAction::back(kpackage->management->treeList, TQ_SLOT(previous()),
 			       actionCollection(),"pack_prev");
 
-  pack_next = KStdAction::forward(TQT_TQOBJECT(kpackage->management->treeList), TQT_SLOT(next()),
+  pack_next = KStdAction::forward(kpackage->management->treeList, TQ_SLOT(next()),
 				  actionCollection(),"pack_next");
 
   (void) (new TDEAction( i18n("&Expand Tree"), "ftout",
-		       0, TQT_TQOBJECT(kpackage),
-		       TQT_SLOT(expandTree()), actionCollection(), "kpack_expand"));
+		       0, kpackage,
+		       TQ_SLOT(expandTree()), actionCollection(), "kpack_expand"));
 
   (void) (new TDEAction( i18n("&Collapse Tree"), "ftin",
-		       0, TQT_TQOBJECT(kpackage),
-		       TQT_SLOT(collapseTree()), actionCollection(), "kpack_collapse"));
+		       0, kpackage,
+		       TQ_SLOT(collapseTree()), actionCollection(), "kpack_collapse"));
 
   (void) (new TDEAction( i18n("Clear &Marked"), TQString(),
-		       0, TQT_TQOBJECT(kpackage),
-		       TQT_SLOT(clearMarked()), actionCollection(), "kpack_clear"));
+		       0, kpackage,
+		       TQ_SLOT(clearMarked()), actionCollection(), "kpack_clear"));
 
   (void) (new TDEAction( i18n("Mark &All"), TQString(),
-		       0, TQT_TQOBJECT(kpackage),
-		       TQT_SLOT(markAll()), actionCollection(), "kpack_markall"));
+		       0, kpackage,
+		       TQ_SLOT(markAll()), actionCollection(), "kpack_markall"));
 
   pack_install = new TDEAction( i18n("&Install"), TQString(),
-			      0, TQT_TQOBJECT(kpackage->management),
-			      TQT_SLOT(installSingleClicked()), actionCollection(), "install_single");
+			      0, kpackage->management,
+			      TQ_SLOT(installSingleClicked()), actionCollection(), "install_single");
 
   pack_install->setEnabled(false);
   kpackage->management->setInstallAction(pack_install);
 
 
   pack_uninstall = new TDEAction( i18n("&Uninstall"), TQString(),
-				0, TQT_TQOBJECT(kpackage->management),
-				TQT_SLOT(uninstallSingleClicked()), actionCollection(), "uninstall_single");
+				0, kpackage->management,
+				TQ_SLOT(uninstallSingleClicked()), actionCollection(), "uninstall_single");
 
   pack_uninstall->setEnabled(false);
   kpackage->management->setUninstallAction(pack_uninstall);
 
 
   (void) (new TDEAction( i18n("&Install Marked"), TQString(),
-		       0, TQT_TQOBJECT(kpackage->management),
-		       TQT_SLOT(installMultClicked()), actionCollection(), "install_marked"));
+		       0, kpackage->management,
+		       TQ_SLOT(installMultClicked()), actionCollection(), "install_marked"));
 
   (void) (new TDEAction( i18n("&Uninstall Marked"), TQString(),
-		       0, TQT_TQOBJECT(kpackage->management),
-		       TQT_SLOT(uninstallMultClicked()), actionCollection(), "uninstall_marked"));
+		       0, kpackage->management,
+		       TQ_SLOT(uninstallMultClicked()), actionCollection(), "uninstall_marked"));
 
   setStandardToolBarMenuEnabled(true);
 
-  KStdAction::configureToolbars( TQT_TQOBJECT(this), TQT_SLOT(configureToolBars()),
+  KStdAction::configureToolbars( this, TQ_SLOT(configureToolBars()),
 				 actionCollection());
 
-  KStdAction::saveOptions( TQT_TQOBJECT(this), TQT_SLOT(saveSettings()), actionCollection());
+  KStdAction::saveOptions( this, TQ_SLOT(saveSettings()), actionCollection());
 
-  KStdAction::keyBindings( guiFactory(), TQT_SLOT(configureShortcuts()), actionCollection());
+  KStdAction::keyBindings( guiFactory(), TQ_SLOT(configureShortcuts()), actionCollection());
 
   (void) (new TDEAction( i18n("Configure &KPackage..."), "configure",
-		       0, TQT_TQOBJECT(this),
-		       TQT_SLOT(setOptions()), actionCollection(), "kpack_options"));
+		       0, this,
+		       TQ_SLOT(setOptions()), actionCollection(), "kpack_options"));
 
   (void) (new TDEAction( i18n("Clear Package &Folder Cache"), TQString(),
-		       0, TQT_TQOBJECT(this),
-		       TQT_SLOT(clearDCache()), actionCollection(), "clear_dcache"));
+		       0, this,
+		       TQ_SLOT(clearDCache()), actionCollection(), "clear_dcache"));
 
   (void) (new TDEAction( i18n("Clear &Package Cache"), TQString(),
-		       0, TQT_TQOBJECT(this),
-		       TQT_SLOT(clearPCache()), actionCollection(), "clear_pcache"));
+		       0, this,
+		       TQ_SLOT(clearPCache()), actionCollection(), "clear_pcache"));
 
   int i;
   for (i = 0; i < kpinterfaceN; i++) {
@@ -239,7 +239,7 @@ void KPKG::add_recent_file(const TQString &newfile){
 
 void KPKG::configureToolBars() {
   KEditToolbar dlg(actionCollection());
-  connect(&dlg,TQT_SIGNAL(newToolbarConfig()),this,TQT_SLOT(slotNewToolbarConfig()));
+  connect(&dlg,TQ_SIGNAL(newToolbarConfig()),this,TQ_SLOT(slotNewToolbarConfig()));
   dlg.exec();
 }
 
